==> tomodachi_testcontainers-0.10.4-py3-none-any.whl: tomodachi_testcontainers/containers/postgres.py <==
"""PostgreSQL testcontainer.

Adaptation of https://github.com/testcontainers/testcontainers-python/tree/main/postgres
"""
import os
from typing import Any, Optional

from tomodachi_testcontainers.containers.common import DatabaseContainer


class PostgreSQLContainer(DatabaseContainer):
    def __init__(
        self,
        image: str = "postgres:16",
        internal_port: int = 5432,
        edge_port: int = 5432,
        drivername: Optional[str] = None,
        username: Optional[str] = None,
        password: Optional[str] = None,
        database: Optional[str] = None,
        **kwargs: Any,
    ) -> None:
        super().__init__(image, internal_port=internal_port, edge_port=edge_port, **kwargs)

        self.drivername = drivername or os.getenv("POSTGRES_DRIVERNAME") or "postgresql+psycopg2"
        self.username = username or os.getenv("POSTGRES_USER") or "username"
        self.password = password or os.getenv("POSTGRES_PASSWORD") or "password"
        self.database = database or os.getenv("POSTGRES_DB") or "db"

        self.with_env("POSTGRES_USER", self.username)
        self.with_env("POSTGRES_PASSWORD", self.password)
        self.with_env("POSTGRES_DB", self.database)

        # Do not flush data on disk to improve test container performance
        # https://pythonspeed.com/articles/faster-db-tests/
        self.with_command("-c fsync=off")

    def log_message_on_container_start(self) -> str:
        return f"PostgreSQL started: {self.get_external_url()}"

==> tomodachi_testcontainers-1.2.2-py3-none-any.whl: tomodachi_testcontainers/containers/postgres.py <==
"""PostgreSQL testcontainer.

Adaptation of https://github.com/testcontainers/testcontainers-python/tree/main/postgres
"""

import os
from typing import Any, Optional

from .common import DatabaseContainer


class PostgreSQLContainer(DatabaseContainer):
    """PostgreSQL container.

    Configuration environment variables (set on host machine):

    - `POSTGRES_DRIVERNAME` - defaults to `postgresql+psycopg`
    - `POSTGRES_USER` - defaults to `username`
    - `POSTGRES_PASSWORD` - defaults to `password`
    - `POSTGRES_DB` - defaults to `db`
    """

    def __init__(
        self,
        image: str = "postgres:16",
        internal_port: int = 5432,
        edge_port: Optional[int] = None,
        drivername: Optional[str] = None,
        username: Optional[str] = None,
        password: Optional[str] = None,
        database: Optional[str] = None,
        disable_logging: bool = False,
        **kwargs: Any,
    ) -> None:
        super().__init__(
            image,
            internal_port=internal_port,
            edge_port=edge_port,
            disable_logging=disable_logging,
            **kwargs,
        )

        self.drivername = drivername or os.getenv("POSTGRES_DRIVERNAME") or "postgresql+psycopg"
        self.username = username or os.getenv("POSTGRES_USER") or "username"
        self.password = password or os.getenv("POSTGRES_PASSWORD") or "password"
        self.database = database or os.getenv("POSTGRES_DB") or "db"

        self.with_env("POSTGRES_USER", self.username)
        self.with_env("POSTGRES_PASSWORD", self.password)
        self.with_env("POSTGRES_DB", self.database)

        # Do not flush data on disk to improve test container performance
        # https://pythonspeed.com/articles/faster-db-tests/
        self.with_command("-c fsync=off")

    def log_message_on_container_start(self) -> str:
        return f"PostgreSQL started: {self.get_external_url()}"
